// SPDX-FileCopyrightText: 2021 GNOME Foundation
// SPDX-License-Identifier: LGPL-2.1-or-later

// Copied from GTK

// A map between namespaces and base URLs for their online documentation
baseURLs = [
    ['GLib', 'https://docs.gtk.org/glib/'],
    ['Gio', 'https://docs.gtk.org/gio/'],
    ['GObject', 'https://docs.gtk.org/gobject/'],
    ['Gdk', 'https://docs.gtk.org/gdk4/'],
    ['Gsk', 'https://docs.gtk.org/gsk4/'],
    ['Gtk', 'https://docs.gtk.org/gtk4/'],
    ['Pango', 'https://docs.gtk.org/Pango/'],
    ['Gly', 'https://gnome.pages.gitlab.gnome.org/glycin/libglycin/'],
]
